Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GitkubeV1alpha1Client ¶
type GitkubeV1alpha1Client struct {
// contains filtered or unexported fields
}
GitkubeV1alpha1Client is used to interact with features provided by the gitkube.sh group.
func New ¶
func New(c rest.Interface) *GitkubeV1alpha1Client
New creates a new GitkubeV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*GitkubeV1alpha1Client, error)
NewForConfig creates a new GitkubeV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *GitkubeV1alpha1Client
NewForConfigOrDie creates a new GitkubeV1alpha1Client for the given config and panics if there is an error in the config.
func (*GitkubeV1alpha1Client) RESTClient ¶
func (c *GitkubeV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*GitkubeV1alpha1Client) Remotes ¶
func (c *GitkubeV1alpha1Client) Remotes(namespace string) RemoteInterface
type GitkubeV1alpha1Interface ¶
type GitkubeV1alpha1Interface interface {
RESTClient() rest.Interface
RemotesGetter
}
type RemoteExpansion ¶
type RemoteExpansion interface{}
type RemoteInterface ¶
type RemoteInterface interface {
Create(*v1alpha1.Remote) (*v1alpha1.Remote, error)
Update(*v1alpha1.Remote) (*v1alpha1.Remote, error)
UpdateStatus(*v1alpha1.Remote) (*v1alpha1.Remote, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Remote, error)
List(opts v1.ListOptions) (*v1alpha1.RemoteList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Remote, err error)
RemoteExpansion
}
RemoteInterface has methods to work with Remote resources.
type RemotesGetter ¶
type RemotesGetter interface {
Remotes(namespace string) RemoteInterface
}
RemotesGetter has a method to return a RemoteInterface. A group's client should implement this interface.