Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RemoteLister ¶
type RemoteLister interface {
// List lists all Remotes in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Remote, err error)
// Remotes returns an object that can list and get Remotes.
Remotes(namespace string) RemoteNamespaceLister
RemoteListerExpansion
}
RemoteLister helps list Remotes.
func NewRemoteLister ¶
func NewRemoteLister(indexer cache.Indexer) RemoteLister
NewRemoteLister returns a new RemoteLister.
type RemoteListerExpansion ¶
type RemoteListerExpansion interface{}
RemoteListerExpansion allows custom methods to be added to RemoteLister.
type RemoteNamespaceLister ¶
type RemoteNamespaceLister interface {
// List lists all Remotes in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.Remote, err error)
// Get retrieves the Remote from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.Remote, error)
RemoteNamespaceListerExpansion
}
RemoteNamespaceLister helps list and get Remotes.
type RemoteNamespaceListerExpansion ¶
type RemoteNamespaceListerExpansion interface{}
RemoteNamespaceListerExpansion allows custom methods to be added to RemoteNamespaceLister.
Click to show internal directories.
Click to hide internal directories.